@@ -1,6 +1,6 @@
 from nb_log.set_nb_log_config import use_config_form_nb_log_config_module
 from nb_log import nb_log_config_default
-from nb_log.monkey_print import nb_print, patch_print, reverse_patch_print,stdout_write,stderr_write
+from nb_log.monkey_print import nb_print, patch_print, reverse_patch_print,stdout_write,stderr_write,print_raw
 from nb_log.log_manager import LogManager, LoggerLevelSetterMixin, LoggerMixin, LoggerMixinDefaultWithFileHandler, get_logger, get_logger_with_filehanlder
 
 if nb_log_config_default.WARNING_PYCHARM_COLOR_SETINGS:
